@@ -698,6 +698,39 @@ class DataframeType(BaseType):
             results |= self.value.apply(lambda row: vlm["filter"](row) and vlm["length_check"](row), axis=1)
         return pd.Series(results.values)
 
+    @type_operator(FIELD_DATAFRAME)
+    def has_next_corresponding_record(self, other_value: dict):
+        """
+        The operator ensures that value of target in current row
+        is the same as value of comparator in the next row.
+        In order to achieve this, we just remove last row from target
+        and first row from comparator and compare the resulting contents.
+        The result is reported for target.
+        """
+        target = self.replace_prefix(other_value.get("target"))
+        comparator = self.replace_prefix(other_value.get("comparator"))
+        group_by_column: str = self.replace_prefix(other_value.get("within"))
+        order_by_column: str = self.replace_prefix(other_value.get("ordering"))
+        ordered_df = self.value.sort_values(by=[order_by_column])
+        grouped_df = ordered_df.groupby(group_by_column)
+        results = grouped_df.apply(lambda x: self.compare_target_with_comparator_next_row(x, target, comparator))
+        return pd.Series(results.explode().tolist())
+
+    @type_operator(FIELD_DATAFRAME)
+    def does_not_have_next_corresponding_record(self, other_value: dict):
+        return ~self.has_next_corresponding_record(other_value)
+
+    def compare_target_with_comparator_next_row(self, df: pd.DataFrame, target: str, comparator: str):
+        """
+        Compares current row of a target with the next row of comparator.
+        We can't compare last row of target with the next row of comparator
+        because there is no row after the last one.
+        """
+        target_without_last_row = df[target].drop(df[target].tail(1).index)
+        comparator_without_first_row = df[comparator].drop(df[comparator].head(1).index)
+        results = np.where(target_without_last_row.values == comparator_without_first_row.values, True, False)
+        return [*results, pandas.NA]  # appending NA here to make the length of results list the same as length of df
+
     def detect_reference(self, row, value_column, target_column, context=None):
         if context:
             target_data = self.relationship_data.get(row[context], {}).get(row[target_column], pd.Series([]).values)
